<?php

namespace Drupal\protected_download;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\StreamWrapper\StreamWrapperManager;
use Drupal\Core\Url;

class LinkGenerator implements LinkGeneratorInterface
{

  /**
   * @var \Drupal\protected_download\SecurityKeyInterface
   */
  protected $securityKey;

  /**
   * The protected download policy repository.
   *
   * @var \Drupal\protected_download\PolicyRepositoryInterface
   */
  protected $policyRepository;

  /**
   * The request time.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * Constructs a new link generator.
   *
   * @param \Drupal\protected_download\SecurityKeyInterface
   *   The protected download security key service.
   * @param \Drupal\protected_download\PolicyRepositoryInterface
   *   The protected download config repository.
   * @param \Drupal\Component\Datetime\TimeInterface
   *   The request time service.
   */
  public function __construct(
    SecurityKeyInterface $security_key,
    PolicyRepositoryInterface $policy_repository,
    TimeInterface $time
  ) {
    $this->securityKey = $security_key;
    $this->policyRepository = $policy_repository;
    $this->time = $time;
  }

  /**
   * {@inheritdoc}
   */
  public function generate($uri, $expire = NULL) {
    $result = FALSE;

    $scheme = StreamWrapperManager::getScheme($uri);
    $target = StreamWrapperManager::getTarget($uri);

    if ($scheme !== FALSE && $target !== FALSE) {
      if (!isset($expire)) {
        $policy = $this->policyRepository->getPolicy($scheme);
        $expire = $policy->expire($this->time->getRequestTime());
      }
      $expire_string = dechex($expire);

      $hmac = $this->securityKey->generate($uri, $expire_string);
      $result = Url::fromRoute('protected_download.link', [
        'scheme' => $scheme,
        'expire' => $expire_string,
        'hmac' => $hmac,
        'filepath' => $target,
      ], [
        'path_processing' => FALSE,
      ]);
    }

    return $result;
  }

}
