<?php

namespace Drupal\protected_download\PathProcessor;

use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Defines a path processor to rewrite protected download URLs.
 *
 * As the route system does not allow arbitrary amount of parameters convert
 * the file path to a query parameter on the request.
 */
class ProtectedDownloadProcessor implements InboundPathProcessorInterface {

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request) {
    $result = $path;

    if (strpos($path, '/protected-download/') === 0 && !$request->query->has('file')) {
      $rest = preg_replace('|^\/protected-download\/|', '', $path);
      [$scheme, $expire, $hmac, $file] = explode("/", $rest, 4);
      $request->query->set('file', $file);
      $result = implode('/', ['/protected-download', $scheme, $expire, $hmac]);
    }

    return $result;
  }

}
